==================
Computer Spy Games
==================

.. image:: cover.jpg

`Download the original book <https://drive.google.com/open?id=0Bxv0SsvibDMTdGY0VEQzSGZnelU>`__



.. toctree::
   :maxdepth: 1

   spy_eyes/index
   searchlight/index
   robospy/index
   spy_q_test/index
   secret_message_maker/index
   rendezvous/index
   morse_coder/index

